@@ -197,7 +197,7 @@ DialogTimingProcessor::DialogTimingProcessor(agi::Context *c)
 	make_ctrl(&d, adjBoxes, _("Max overlap:"), &adjOverlap, adjsEnable,
 		_("Maximum overlap between the end and start time for two subtitles to be made continuous, in milliseconds"));
 
-	adjacentBias = new wxSlider(&d, -1, mid<int>(0, OPT_GET("Tool/Timing Post Processor/Adjacent Bias")->GetDouble() * 100, 100), 0, 100);
+	adjacentBias = new wxSlider(&d, -1, mid<int>(0, OPT_GET("Tool/Timing Post Processor/Adjacent Bias")->GetDouble() * 100, 100), 0, 100, wxDefaultPosition, wxSize(-1,20));
 	adjacentBias->SetToolTip(_("Sets how to set the adjoining of lines. If set totally to left, it will extend or shrink start time of the second line; if totally to right, it will extend or shrink the end time of the first line."));
 
 	auto adjSliderSizer = new wxBoxSizer(wxHORIZONTAL);
@@ -407,12 +407,9 @@ void DialogTimingProcessor::Process() {
 			AssDialogue *prev = sorted[i - 1];
 			AssDialogue *cur = sorted[i];
 
-			// Raw millisecond values are used in this step instead of the typical centisecond.
-			// In this step, we need to distinguish between gap and overlap, as they have different thresholds.
-			// A small gap / overlap less than 1 centisecond may not be distinguishable using rounded centisecond values.
-			int dist = cur->Start.GetMillisecond() - prev->End.GetMillisecond();
+			int dist = cur->Start - prev->End;
 			if ((dist < 0 && -dist <= adjOverlap) || (dist > 0 && dist <= adjGap)) {
-				int setPos = prev->End.GetMillisecond() + int(dist * bias + 0.5);
+				int setPos = prev->End + int(dist * bias);
 				cur->Start = setPos;
 				prev->End = setPos;
 			}
